@@ -9,6 +9,7 @@ from flask_discord_interactions.context import (
     AsyncContext,
     CommandOptionType,
     ChannelType,
+    Permission,
     Member,
     User,
     Role,
@@ -29,7 +30,9 @@ from flask_discord_interactions.component import (
     ActionRow,
     Button,
     ButtonStyles,
-    ComponentType
+    ComponentType,
+    SelectMenu,
+    SelectMenuOption
 )
 from flask_discord_interactions.client import Client
 
