@@ -1,3 +1,4 @@
+import re
 import enum
 import inspect
 import itertools
@@ -33,24 +34,41 @@ class SlashCommand:
         annotations. Do not use with ``options``. If omitted, and if
         ``options`` is not provided, option descriptions default to
         "No description".
+    default_permission
+        Whether the command is enabled by default. Default is True.
+    permissions
+        List of permission overwrites.
     """
 
-    def __init__(self, command, name, description, options, annotations):
+    def __init__(self, command, name, description, options, annotations,
+                 default_permission=True, permissions=None):
         self.command = command
         self.name = name
         self.description = description
         self.options = options
         self.annotations = annotations or {}
+        self.default_permission = default_permission
+        self.permissions = permissions or []
 
         if self.name is None:
             self.name = command.__name__
         if self.description is None:
             self.description = command.__doc__ or "No description"
 
-        if not 3 <= len(self.name) <= 32:
+        if not 1 <= len(self.name) <= 32:
             raise ValueError(
                 f"Error adding command {self.name}: "
-                "Command name must be between 3 and 32 characters.")
+                "Command name must be between 1 and 32 characters.")
+        if self.name != self.name.lower():
+            raise ValueError(
+                f"Error adding command {self.name}: "
+                "Command name must be fully lowercase. "
+                "No UPPERCASE or CamelCase names are allowed.")
+        if not re.fullmatch(r"^[\w-]{1,32}$", self.name):
+            raise ValueError(
+                f"Error adding command {self.name}: "
+                "Command name does not match regex. "
+                "(Perhaps it contains an invalid character?)")
         if not 1 <= len(self.description) <= 100:
             raise ValueError(
                 f"Error adding command {self.name}: "
@@ -74,6 +92,8 @@ class SlashCommand:
                     ptype = CommandOptionType.BOOLEAN
                 elif annotation == str:
                     ptype = CommandOptionType.STRING
+                elif annotation == float:
+                    ptype = CommandOptionType.NUMBER
 
                 # Discord Models
                 elif annotation in [User, Member]:
@@ -143,8 +163,7 @@ class SlashCommand:
             context = AsyncContext.from_data(discord, app, data)
         else:
             context = Context.from_data(discord, app, data)
-        args, kwargs = context.create_args(
-            data["data"], resolved=data["data"].get("resolved"))
+        args, kwargs = context.create_args()
 
         result = self.run(context, *args, **kwargs)
 
@@ -171,9 +190,13 @@ class SlashCommand:
         return {
             "name": self.name,
             "description": self.description,
-            "options": self.options
+            "options": self.options,
+            "default_permission": self.default_permission
         }
 
+    def dump_permissions(self):
+        return [permission.dump() for permission in self.permissions]
+
 
 class SlashCommandSubgroup(SlashCommand):
     """
@@ -185,13 +208,21 @@ class SlashCommandSubgroup(SlashCommand):
         The name of this subgroup, shown in the Discord client.
     description
         The description of this subgroup, shown in the Discord client.
+    is_async
+        Whether the subgroup should be considered async (if subcommands
+        get an :class:`AsyncContext` instead of a :class:`Context`.)
     """
 
-    def __init__(self, name, description):
+    def __init__(self, name, description, is_async=False):
         self.name = name
         self.description = description
         self.subcommands = {}
 
+        self.default_permission = None
+        self.permissions = []
+
+        self.is_async = is_async
+
     def command(self, name=None, description=None,
                 options=None, annotations=None):
         """
@@ -255,32 +286,7 @@ class SlashCommandSubgroup(SlashCommand):
 
 
 class SlashCommandGroup(SlashCommandSubgroup):
-    def make_context_and_run(self, discord, app, data):
-        """
-        Creates the :class:`Context` for an invocation of this slash command
-        group, then invokes itself.
-
-        Parameters
-        ----------
-        discord
-            The :class:`DiscordInteractions` object used to receive this
-            interaction.
-        app
-            The Flask app used to receive this interaction.
-        data
-            The incoming interaction data.
-        """
-
-        context = Context.from_data(discord, app, data)
-
-        subcommands, kwargs = context.create_args(
-            data["data"], resolved=data["data"].get("resolved"))
-
-        result = self.run(context, *subcommands, **kwargs)
-
-        return Response.from_return_value(result)
-
-    def subgroup(self, name, description="No description"):
+    def subgroup(self, name, description="No description", is_async=False):
         """
         Create a new :class:`SlashCommandSubroup`
         (which can contain multiple subcommands)
@@ -291,8 +297,11 @@ class SlashCommandGroup(SlashCommandSubgroup):
             The name of the subgroup, as displayed in the Discord client.
         description
             The description of the subgroup. Defaults to "No description".
+        is_async
+            Whether the subgroup should be considered async (if subcommands
+            get an :class:`AsyncContext` instead of a :class:`Context`.)
         """
 
-        group = SlashCommandSubgroup(name, description)
+        group = SlashCommandSubgroup(name, description, is_async)
         self.subcommands[name] = group
         return group
